@@ -1178,7 +1178,7 @@ use Tk;
 use Tk::ItemStyle;
 use base qw(Tk::Derived Tk::HList);
 use vars qw($VERSION @Selection $Prev $tixIndicatorArmed);
-$VERSION = '2.41';
+$VERSION = '2.42';
 
 Tk::Widget->Construct('HListbox');
 
@@ -1535,11 +1535,11 @@ sub selectionClear {
 sub anchorSet {  #HList's "anchor" is it's (active) cursor, so we use a "virtual anchor" for ours.
 	my ($w) = shift;
 	return  if ($w->{Configure}{'-state'} =~ /d/o);
-	return  unless (defined($_[1]) && $_[1] =~ /\S/o);
+	return  unless (defined($_[0]) && $_[0] =~ /\S/o);
 
-	my $ent = $_[0]->getEntry($_[1]);
-	$_[0]->{'_vanchor'} = (!defined($ent) || $_[0]->entrycget($ent, '-state') eq 'disabled' || $_[0]->info('hidden', $ent))
-			? undef : $_[0]->index($_[1]);
+	my $ent = $w->getEntry($_[0]);
+	$w->{'_vanchor'} = (!defined($ent) || $w->entrycget($ent, '-state') eq 'disabled' || $w->info('hidden', $ent))
+			? undef : $w->index($_[0]);
 }
 
 sub anchorClear {
